@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::PluginBundle::NGLENN;
 # ABSTRACT: Dist::Zilla plugin configuration for me
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # Dependencies
 use Moose 0.99;
@@ -413,12 +413,6 @@ sub configure {
         # Note -- NextRelease is here to get the ordering right with
         # git actions.  It is *also* a file munger that acts earlier
 
-        (
-            $self->no_git
-            ? ()
-            : ( [ 'Git::Tag' => { tag_format => $self->tag_format } ], )
-        ),
-
         # bumps Changes
         'NextRelease', # core (also munges files)
 
@@ -436,12 +430,13 @@ sub configure {
                             allow_dirty       => [qw/Changes Makefile.PL/],
                             allow_dirty_match => '^lib|^bin',
                         )
-                    }
+                    },
+                    'Git::Tag' => { tag_format => $self->tag_format }
                 ],
                 [ 'Git::Push' => { push_to => \@push_to } ],
                 'GitHub::UploadRelease'
             )
-        ),
+        )
 
     );
 
@@ -473,7 +468,7 @@ Dist::Zilla::PluginBundle::NGLENN - Dist::Zilla plugin configuration for me
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
